/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_ABI_FORMAT_H_
#define _GB2_ABI_FORMAT_H_

#include <core_api/DocumentFormats.h>
#include <core_api/DocumentModel.h>

namespace GB2 {

class IOAdapter;
class SeekableBuf;

class GB2_COREAPI_EXPORT  ABIFormat : public DocumentFormat {
    Q_OBJECT
public:
	ABIFormat(QObject* p);

	virtual DocumentFormatId getFormatId() const {return BaseDocumentFormats::ABIF;}

	virtual const QString& getFormatName() const {return formatName;}

    virtual Document* loadDocument(IOAdapter* io, TaskStateInfo& ti, const QVariantMap& fs, DocumentLoadMode mode = DocumentLoadMode_Whole);

    virtual bool checkRawData(const QByteArray& rawData) const;
    
private:
    Document* parseABI(SeekableBuf*, IOAdapter* io, const QVariantMap& fs);
	QString formatName;
};

}//namespace

#endif
